@@ -32,9 +32,6 @@ Vue.component('finished-table', {
         </a>
         <div class="subtitle">{{ upload.dataset.uuid }}</div>
       </div>
-      <div v-else>
-        <span class="subtitle">(no dataset)</span>
-      </div>
     </td>
     <td>
       <div v-if="upload.night_log && upload.night_log.date">
@@ -46,22 +43,19 @@ Vue.component('finished-table', {
         </a>
         <div class="subtitle">{{ upload.night_log.uuid }}</div>
       </div>
-      <div v-else>
-        <span class="subtitle">(no night log)</span>
-      </div>
     </td>
     <td>
       <div v-if="upload.telescope">
         {{ upload.telescope.name }}
         <div class="subtitle">{{ upload.telescope.uuid }}</div>
       </div>
-      <div v-else>
+      <div v-else-if="!upload.telescope && !upload.substatus.toLowerCase().startsWith('skipped')">
         <span class="subtitle">(no telescope)</span>
       </div>
     </td>
     <td>
       <a v-if="upload.organisation" :href='getOrganisationURL(upload)' target="_blank">{{ upload.organisation.subdomain }}</a>
-      <a v-else :href='getProfileURL(upload)' target="_blank">@{{ upload.astronomer }}</a>
+      <a v-else-if="upload.astronomer" :href='getProfileURL(upload)' target="_blank">@{{ upload.astronomer }}</a>
     </td>
     <td>
       {{ getFormattedSize(upload.file_size) }}
@@ -72,8 +66,22 @@ Vue.component('finished-table', {
       </div>
       <div class="subtitle">{{ upload.substatus }}</div>
     </td>
-    <td>{{ upload.started }}</td>
-    <td>{{ upload.ended }}</td>
+    <td>
+      <div>
+        {{ upload.started }}
+      </div>
+      <div class="subtitle">
+        {{ getTimeAgoString(upload.started) }}
+       </div>
+    </td>
+    <td>
+      <div>
+        {{ upload.ended }}
+      </div>
+      <div class="subtitle">
+        {{ getTimeAgoString(upload.ended) }}
+       </div>
+    </td>
     <td>{{ upload.duration.toFixed(1) }} s</td>
     <td>{{ upload.error }}</td>
   </tr>
@@ -94,7 +102,7 @@ Vue.component('finished-table', {
     }
   },
   methods: {
-    getFilePath(upload) {
+    getFilePath (upload) {
       return upload.file_path.replace(this.root_path, '')
     },
     getOrganisationDatasetURL (upload) {
@@ -125,6 +133,21 @@ Vue.component('finished-table', {
     },
     getStatusStyle (upload) {
       return { color: upload.substatus.toLowerCase().startsWith('skipped') ? 'orange' : 'green' }
+    },
+    getTimeAgoString (date) {
+      if (!date) {
+        return ''
+      }
+      const seconds = Math.ceil((new Date() - new Date(date)) / 1000)
+      if (seconds < 60) {
+        return 'moments ago'
+      } else if (seconds < 3600) {
+        return (seconds / 60).toFixed(1).toString() + ' minutes ago'
+      } else if (seconds < 3600 * 24) {
+        return (seconds / 3600).toFixed(1).toString() + ' hours ago'
+      } else {
+        return (seconds / 3600 / 24).toFixed(1).toString() + ' days ago'
+      }
     }
   }
 })
