@@ -1,9 +1,10 @@
 import logging
 import os
-
 from configparser import ConfigParser
 from typing import Dict, List
 
+from oort.shared.constants import OORT_SUPERVISOR_SOCK_FILENAME
+
 
 def get_directory_path():
     d = os.path.expanduser('~/.oort')
@@ -17,19 +18,23 @@ def get_oort_config_file_path():
 
 
 def get_config_socket_file_path():
-    return os.path.join(get_directory_path(), 'supervisor.sock')
+    return os.path.join(get_directory_path(), OORT_SUPERVISOR_SOCK_FILENAME)
 
 
 def get_supervisord_log_file_path():
     return os.path.join(get_directory_path(), 'supervisord.log')
 
 
+def get_supervisord_pid_file_path():
+    return os.path.join(get_directory_path(), 'supervisord.pid')
+
+
 def get_log_file_path():
     return os.path.join(get_directory_path(), 'oort.log')
 
 
 def get_db_file_path():
-    suffix = '-tests' if os.environ.get('TESTS') == 'True' else ''
+    suffix = '-tests' if os.environ.get('OORT_TESTS') == 'True' else ''
     return os.path.join(get_directory_path(), f'uploads{suffix}.db')
 
 
@@ -38,7 +43,7 @@ def get_supervisor_conf_file_path():
 
 
 def get_logger(debug=False):
-    suffix = '-tests' if os.environ.get('TESTS') == 'True' else ''
+    suffix = '-tests' if os.environ.get('OORT_TESTS') == 'True' else ''
     logger = logging.getLogger('oort-cloud' + suffix)
     logger.setLevel(logging.DEBUG if debug else logging.INFO)
 
