@@ -1,30 +1,30 @@
 import os
-from typing import Optional, Type
+from typing import Optional, Type, Union
 
 from arcsecond import ArcsecondAPI
+from peewee import DoesNotExist
+
 from oort.shared.config import get_logger
-from oort.shared.identity import Identity
 from oort.shared.models import (
-    BaseModel,
+    Model,
     Dataset,
     NightLog,
     Organisation,
     Status,
     Substatus,
-    Telescope
+    Telescope,
+    Observation,
+    Calibration
 )
-from peewee import DoesNotExist
-
-from .errors import UploadPreparationAPIError, UploadPreparationError, UploadPreparationFatalError
-from .packer import UploadPack
+from . import errors
 
 
 class UploadPreparator(object):
     """Sync remote Telescope, Night Log, Observation or Calibration and Dataset."""
 
-    def __init__(self, pack: UploadPack, identity: Identity, debug=False):
+    def __init__(self, pack, debug=False):
         self._pack = pack
-        self._identity = identity
+        self._identity = self._pack.identity
         self._debug = debug
         self._logger = get_logger(debug=self._debug)
 
@@ -40,21 +40,13 @@ class UploadPreparator(object):
         # Do NOT mix debug and self._identity.debug
 
         self._pack.upload.smart_update(astronomer=self._identity.username)
-        if self._identity.organisation:
+        if self._identity.subdomain:
             api = ArcsecondAPI.organisations(debug=self._identity.debug)
-            self._organisation = self._sync_local_resource(Organisation, api, self._identity.organisation)
+            self._organisation = self._sync_local_resource(Organisation, api, self._identity.subdomain)
             self._pack.upload.smart_update(organisation=self._organisation)
 
     # ------ PROPERTIES ------------------------------------------------------------------------------------------------
 
-    @property
-    def pack(self) -> UploadPack:
-        return self._pack
-
-    @property
-    def identity(self) -> Identity:
-        return self._identity
-
     @property
     def preparation_succeeded(self) -> bool:
         return False
@@ -62,49 +54,55 @@ class UploadPreparator(object):
     @property
     def api_kwargs(self) -> dict:
         kwargs = {'debug': self._identity.debug}
-        if self._identity.organisation is not None and len(self._identity.organisation) > 0:
-            kwargs.update(organisation=self._identity.organisation)
+        if self._identity.subdomain is not None and len(self._identity.subdomain) > 0:
+            kwargs.update(organisation=self._identity.subdomain)
         else:
             kwargs.update(api_key=self._identity.api_key)
         return kwargs
 
     @property
-    def telescope(self) -> Optional[dict]:
+    def telescope(self) -> Optional[Telescope]:
         return self._telescope
 
     @property
-    def night_log(self) -> Optional[BaseModel]:
+    def night_log(self) -> Optional[NightLog]:
         return self._night_log
 
     @property
-    def obs_or_calib(self) -> Optional[BaseModel]:
+    def obs_or_calib(self) -> Optional[Union[Observation, Calibration]]:
         return self._obs_or_calib
 
     @property
-    def dataset(self) -> Optional[BaseModel]:
+    def dataset(self) -> Optional[Dataset]:
         return self._dataset
 
     @property
     def prefix(self) -> str:
-        return '[' + '/'.join(self._pack.file_path.split(os.sep)[-2:]) + ']'
+        return '[UploadPreparator: ' + '/'.join(self._pack.file_path.split(os.sep)[-2:]) + ']'
 
     # ------ SYNC ------------------------------------------------------------------------------------------------------
 
-    def _sync_local_resource(self, db_class: Type[BaseModel], api: ArcsecondAPI, id_value) -> BaseModel:
+    def _sync_local_resource(self, db_class: Type[Model], api: ArcsecondAPI, id_value) -> Model:
         remote_resource, error = api.read(id_value)
         if error:
-            raise UploadPreparationAPIError(str(error))
+            raise errors.UploadPreparationAPIError(str(error))
 
         try:
-            resource = db_class.smart_get(**{db_class._primary_field: id_value})
+            local_resource = db_class.smart_get(**{db_class._primary_field: id_value})
         except DoesNotExist:
-            resource = self._create_local_resource(db_class, **{db_class._primary_field: id_value})
+            kwargs = {db_class._primary_field: id_value}
+            if 'name' in remote_resource.keys():
+                kwargs.update(name=remote_resource.get('name'))
+            local_resource = self._create_local_resource(db_class, **kwargs)
+        else:
+            if 'name' in remote_resource.keys() and 'name' in db_class._meta.sorted_field_names:
+                local_resource.smart_update(name=remote_resource.get('name'))
 
-        return resource
+        return local_resource
 
     # ------------------------------------------------------------------------------------------------------------------
 
-    def _sync_resource(self, db_class: Type[BaseModel], api: ArcsecondAPI, **kwargs) -> BaseModel:
+    def _sync_resource(self, db_class: Type[Model], api: ArcsecondAPI, **kwargs) -> Model:
         try:
             resource = db_class.smart_get(**kwargs)
 
@@ -113,13 +111,13 @@ class UploadPreparator(object):
 
             remote_resource = self._find_or_create_remote_resource(api, **kwargs)
             if remote_resource is None:
-                raise UploadPreparationError('cant create resource')
+                raise errors.UploadPreparationError('cant create resource')
 
             common_keys = kwargs.keys() & remote_resource.keys()
             common_values = [(k, kwargs.get(k), remote_resource.get(k)) for k in common_keys]
             if any([(k, v1, v2) for k, v1, v2 in common_values if v1 != v2]):
                 msg = f'Mismatch between remote and local for {db_class} resource: {common_values}'
-                raise UploadPreparationError(msg)
+                raise errors.UploadPreparationError(msg)
 
             resource = self._create_local_resource(db_class, **remote_resource)
 
@@ -135,7 +133,7 @@ class UploadPreparator(object):
 
         # An error occurred. Deal with it.
         if error is not None:
-            raise UploadPreparationError(str(error))
+            raise errors.UploadPreparationError(str(error))
 
         # Dealing with paginated results
         if isinstance(response_list, dict) and 'results' in response_list.keys():
@@ -153,7 +151,7 @@ class UploadPreparator(object):
         # Multiple resources found ??? Filter is not good, or something fishy is happening.
         else:
             msg = f'Multiple resources found for API {api}? Choosing first.'
-            raise UploadPreparationError(msg)
+            raise errors.UploadPreparationError(msg)
 
         return new_resource
 
@@ -166,20 +164,20 @@ class UploadPreparator(object):
 
         if error is not None:
             msg = f'Failed to create resource in {api} endpoint: {str(error)}'
-            raise UploadPreparationError(msg)
+            raise errors.UploadPreparationError(msg)
         else:
             self._logger.info(f'{self.prefix} Remote resource created.')
             return remote_resource
 
     # ------------------------------------------------------------------------------------------------------------------
 
-    def _create_local_resource(self, db_class: Type[BaseModel], **kwargs):
+    def _create_local_resource(self, db_class: Type[Model], **kwargs):
         self._logger.info(f'{self.prefix} Creating local resource.')
 
         fields = {k: v for k, v in kwargs.items() if k in db_class._meta.sorted_field_names and v is not None}
 
-        if self._identity.organisation and 'organisation' in db_class._meta.sorted_field_names:
-            fields.update(organisation=self._identity.organisation)
+        if self._identity.subdomain and 'organisation' in db_class._meta.sorted_field_names:
+            fields.update(organisation=self._identity.subdomain)
 
         instance = db_class.smart_create(**fields)
         self._logger.info(f'{self.prefix} Local resource created.')
@@ -249,13 +247,13 @@ class UploadPreparator(object):
             if self._dataset:
                 self._pack.upload.smart_update(dataset=self.dataset)
 
-        except UploadPreparationFatalError as e:
+        except errors.UploadPreparationFatalError as e:
             self._logger.info(f'Preparation failed for {self._pack.file_path} with error: {str(e)}')
             self._pack.upload.smart_update(status=Status.ERROR.value, substatus=Substatus.ERROR.value, error=str(e))
             self._preparation_succeeded = False
             self._preparation_can_be_restarted = False
 
-        except UploadPreparationError as e:
+        except errors.UploadPreparationError as e:
             self._logger.info(f'Preparation failed for {self._pack.file_path} with error: {str(e)}')
             self._pack.upload.smart_update(status=Status.ERROR.value, substatus=Substatus.ERROR.value, error=str(e))
             self._preparation_succeeded = False
