@@ -13,5 +13,5 @@ def test_observer_adding_folder_path():
     po = PathsObserver()
     with patch.object(PathsObserver, 'schedule') as mocked_method:
         po.observe_folder('.', Identity('cedric', '123', debug=True))
-        assert mocked_method.called_once_with(ANY, '.', recursive=True)
+        mocked_method.assert_called_once_with(ANY, '.', recursive=True)
         assert po.observed_paths == ['.']
