@@ -4,13 +4,14 @@ import uuid
 from unittest.mock import patch
 
 from arcsecond.api.main import ArcsecondAPI
-from arcsecond.config import config_file_save_api_key, config_file_save_organisation_membership
 
 from oort.shared.identity import Identity
 from oort.shared.models import Calibration, Dataset, NightLog, Observation, Organisation, Telescope, Upload, db
 from oort.uploader.engine.packer import UploadPack
 from oort.uploader.engine.preparator import UploadPreparator
-from tests.utils import use_test_database
+from tests.utils import TEST_API_KEY, TEST_LOGIN_ORG_ROLE, TEST_LOGIN_ORG_SUBDOMAIN, TEST_LOGIN_USERNAME, \
+    save_test_credentials, \
+    use_test_database
 
 spec = importlib.util.find_spec('oort')
 
@@ -42,14 +43,19 @@ def test_preparator_init_no_org():
 
 @use_test_database
 def test_preparator_init_with_org():
-    api_key = str(uuid.uuid4())
-    config_file_save_api_key(api_key, 'cedric', section='debug')
-    config_file_save_organisation_membership('saao', 'admin', section='debug')
+    save_test_credentials()
+
+    identity = Identity(TEST_LOGIN_USERNAME,
+                        TEST_API_KEY,
+                        TEST_LOGIN_ORG_SUBDOMAIN,
+                        TEST_LOGIN_ORG_ROLE,
+                        telescope_uuid)
 
-    identity = Identity('cedric', api_key, 'saao', 'admin', telescope_uuid)
     pack = UploadPack(folder_path, fits_file_path, identity)
-    with patch.object(UploadPreparator, 'prepare'), \
-         patch.object(ArcsecondAPI, 'read', return_value=({'subdomain': 'saao'}, None)) as mock_method_read:
+    with patch.object(ArcsecondAPI, 'is_logged_in', return_value=True), \
+         patch.object(UploadPreparator, 'prepare'), \
+         patch.object(ArcsecondAPI, 'read',
+                      return_value=({'subdomain': TEST_LOGIN_ORG_SUBDOMAIN}, None)) as mock_method_read:
         assert Organisation.select().count() == 0
         prep = UploadPreparator(pack, identity)
 
@@ -60,17 +66,17 @@ def test_preparator_init_with_org():
         assert prep.obs_or_calib is None
         assert prep.dataset is None
 
-        assert mock_method_read.called_once_with(date=pack.night_log_date_string)
-        org = Organisation.select(Organisation.subdomain == 'saao').get()
+        mock_method_read.assert_called_with(TEST_LOGIN_ORG_SUBDOMAIN)
+        # mock_method_read.assert_called_with(date=pack.night_log_date_string)
+        org = Organisation.select(Organisation.subdomain == TEST_LOGIN_ORG_SUBDOMAIN).get()
         assert org is not None
 
 
 @use_test_database
 def test_preparator_prepare_no_org_no_telescope():
-    api_key = str(uuid.uuid4())
-    config_file_save_api_key(api_key, 'cedric', section='debug')
+    save_test_credentials()
 
-    identity = Identity('cedric', api_key, debug=True)
+    identity = Identity(TEST_LOGIN_USERNAME, TEST_API_KEY, debug=True)
     pack = UploadPack(folder_path, fits_file_path, identity)
     assert len(pack.night_log_date_string) > 0
     assert identity.telescope is None
@@ -79,21 +85,27 @@ def test_preparator_prepare_no_org_no_telescope():
     obs = {'uuid': str(uuid.uuid4()), 'night_log': nl['uuid'], 'name': pack.dataset_name}
     ds = {'uuid': str(uuid.uuid4()), 'observation': obs['uuid'], 'name': pack.dataset_name}
 
-    with patch.object(ArcsecondAPI, 'list', return_value=([], None)) as mock_method_list, \
+    with patch.object(ArcsecondAPI, 'is_logged_in', return_value=True), \
+         patch.object(ArcsecondAPI, 'list', return_value=([], None)) as mock_method_list, \
             patch.object(ArcsecondAPI, 'create') as mock_method_create:
         mock_method_create.side_effect = [(nl, None), (obs, None), (ds, None)]
 
         up = UploadPreparator(pack, identity)
         up.prepare()
-        assert mock_method_list.called_once_with(date=pack.night_log_date_string)
-        assert mock_method_create.called_with(**nl)
+
+        mock_method_list.assert_any_call(date=pack.night_log_date_string)
+        mock_method_list.assert_any_call(name=pack.dataset_name, night_log=nl['uuid'], target_name=pack.dataset_name)
+        mock_method_list.assert_any_call(name=pack.dataset_name, observation=obs['uuid'])
+
+        mock_method_create.assert_any_call({'date': pack.night_log_date_string})
         assert up.night_log is not None
         assert up.night_log.uuid == nl['uuid']
 
-        assert mock_method_create.called_with(**obs)
+        payload = {'name': pack.dataset_name, 'night_log': nl['uuid'], 'target_name': pack.dataset_name}
+        mock_method_create.assert_any_call(payload)
         assert up.obs_or_calib is not None
         assert up.obs_or_calib.uuid == obs['uuid']
 
-        assert mock_method_create.called_with(**ds)
+        mock_method_create.assert_any_call({'name': pack.dataset_name, 'observation': obs['uuid']})
         assert up.dataset is not None
         assert up.dataset.uuid == ds['uuid']
